deployers

package
v0.0.0-...-9ccc941 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: Apache-2.0 Imports: 22 Imported by: 1

Documentation

Index

Constants

const (
	AppLabelKey = "app"
)

Variables

This section is empty.

Functions

func AvailableTypes

func AvailableTypes() []string

func CreateApplicationSet

func CreateApplicationSet(ctx types.TestContext, a ApplicationSet) error

nolint:funlen

func CreateKustomizationFile

func CreateKustomizationFile(ctx types.TestContext, dir string) error

func CreateManagedClusterSetBinding

func CreateManagedClusterSetBinding(ctx types.TestContext, name, namespace string) error

func CreatePlacement

func CreatePlacement(ctx types.TestContext, name, namespace string, clusterName string) error

func CreatePlacementDecisionConfigMap

func CreatePlacementDecisionConfigMap(ctx types.TestContext, cmName string, cmNamespace string) error

func CreateSubscription

func CreateSubscription(ctx types.TestContext, s Subscription) error

func DeleteApplicationSet

func DeleteApplicationSet(ctx types.TestContext, a ApplicationSet) error

func DeleteConfigMap

func DeleteConfigMap(ctx types.TestContext, cmName string, cmNamespace string) error

func DeleteDiscoveredApps

func DeleteDiscoveredApps(ctx types.TestContext, cluster *types.Cluster, namespace string) error

func DeleteDiscoveredAppsAndWait

func DeleteDiscoveredAppsAndWait(ctx types.TestContext, cluster *types.Cluster, namespace string) error

func DeleteManagedClusterSetBinding

func DeleteManagedClusterSetBinding(ctx types.TestContext, name, namespace string) error

func DeletePlacement

func DeletePlacement(ctx types.TestContext, name, namespace string) error

func DeleteSubscription

func DeleteSubscription(ctx types.TestContext, s Subscription) error

func New

func New(deployer config.Deployer) (types.Deployer, error)

New creates a new deployer for name

func NewApplicationSet

func NewApplicationSet(deployer config.Deployer) types.Deployer

func NewDiscoveredApp

func NewDiscoveredApp(deployer config.Deployer) types.Deployer

func NewSubscription

func NewSubscription(deployer config.Deployer) types.Deployer

func WaitWorkloadHealth

func WaitWorkloadHealth(ctx types.TestContext, cluster *types.Cluster) error

Types

type ApplicationSet

type ApplicationSet struct {
	DeployerSpec config.Deployer
}

func (ApplicationSet) DeleteResources

func (a ApplicationSet) DeleteResources(ctx types.TestContext) error

func (ApplicationSet) Deploy

func (a ApplicationSet) Deploy(ctx types.TestContext) error

Deploy creates an ApplicationSet on the hub cluster, creating the workload on one of the managed clusters.

func (ApplicationSet) GetConfig

func (a ApplicationSet) GetConfig() *config.Deployer

GetConfig returns the deployer configuration used by the ApplicationSet deployer.

func (ApplicationSet) GetName

func (a ApplicationSet) GetName() string

func (ApplicationSet) GetNamespace

func (a ApplicationSet) GetNamespace(ctx types.TestContext) string

func (ApplicationSet) GetRecipe

func (a ApplicationSet) GetRecipe(ctx types.TestContext) (*recipe.Recipe, error)

GetRecipe returns nil as ApplicationSet deployer does not use Recipe.

func (ApplicationSet) IsDiscovered

func (a ApplicationSet) IsDiscovered() bool

func (ApplicationSet) Undeploy

func (a ApplicationSet) Undeploy(ctx types.TestContext) error

Undeploy deletes an ApplicationSet from the hub cluster, deleting the workload from the managed clusters.

func (ApplicationSet) WaitForResourcesDelete

func (a ApplicationSet) WaitForResourcesDelete(ctx types.TestContext) error

type CombinedData

type CombinedData map[string]interface{}

type DiscoveredApp

type DiscoveredApp struct {
	DeployerSpec config.Deployer
	// contains filtered or unexported fields
}

func (DiscoveredApp) DeleteResources

func (d DiscoveredApp) DeleteResources(ctx types.TestContext) error

func (DiscoveredApp) Deploy

func (d DiscoveredApp) Deploy(ctx types.TestContext) error

Deploy creates a workload on the first managed cluster.

func (DiscoveredApp) GetConfig

func (d DiscoveredApp) GetConfig() *config.Deployer

GetConfig returns the deployer configuration used by the DiscoveredApp deployer.

func (DiscoveredApp) GetName

func (d DiscoveredApp) GetName() string

func (DiscoveredApp) GetNamespace

func (d DiscoveredApp) GetNamespace(ctx types.TestContext) string

func (*DiscoveredApp) GetRecipe

func (d *DiscoveredApp) GetRecipe(ctx types.TestContext) (*recipe.Recipe, error)

GetRecipe returns the recipe associated with the deployer

func (DiscoveredApp) IsDiscovered

func (d DiscoveredApp) IsDiscovered() bool

func (DiscoveredApp) Undeploy

func (d DiscoveredApp) Undeploy(ctx types.TestContext) error

Undeploy deletes the workload from the managed clusters.

func (DiscoveredApp) WaitForResourcesDelete

func (d DiscoveredApp) WaitForResourcesDelete(ctx types.TestContext) error

type Subscription

type Subscription struct {
	DeployerSpec config.Deployer
}

func (Subscription) DeleteResources

func (s Subscription) DeleteResources(ctx types.TestContext) error

func (Subscription) Deploy

func (s Subscription) Deploy(ctx types.TestContext) error

Deploy creates a Subscription on the hub cluster, creating the workload on one of the managed clusters.

func (Subscription) GetConfig

func (s Subscription) GetConfig() *config.Deployer

GetConfig returns the deployer configuration used by the Subscription deployer.

func (Subscription) GetName

func (s Subscription) GetName() string

func (Subscription) GetNamespace

func (s Subscription) GetNamespace(_ types.TestContext) string

func (Subscription) GetRecipe

func (s Subscription) GetRecipe(ctx types.TestContext) (*recipe.Recipe, error)

GetRecipe returns nil as Subscription deployer does not use Recipe.

func (Subscription) IsDiscovered

func (s Subscription) IsDiscovered() bool

func (Subscription) Undeploy

func (s Subscription) Undeploy(ctx types.TestContext) error

Undeploy deletes a subscription from the hub cluster, deleting the workload from the managed clusters.

func (Subscription) WaitForResourcesDelete

func (s Subscription) WaitForResourcesDelete(ctx types.TestContext) error

Jump to